@@ -3,16 +3,11 @@
 # SPDX-License-Identifier: Apache-2.0
 #
 """Tests for `mbed_tools.targets.target_attributes`."""
-import pathlib
-import tempfile
 from unittest import TestCase, mock
 
-from mbed_tools.targets._internal.exceptions import TargetsJsonConfigurationError
 from mbed_tools.targets._internal.target_attributes import (
-    ParsingTargetsJSONError,
     TargetNotFoundError,
     get_target_attributes,
-    _read_json_file,
     _extract_target_attributes,
     _extract_core_labels,
     _apply_config_overrides,
@@ -55,64 +50,26 @@ class TestExtractTargetAttributes(TestCase):
             _extract_target_attributes(all_targets_data, "Target_1"),
 
 
-class TestReadTargetsJSON(TestCase):
-    def test_valid_path(self):
-        contents = """{
-            "Target_Name": {
-                "attribute_1": []
-            }
-        }"""
-        with tempfile.TemporaryDirectory() as directory:
-            json_file = pathlib.Path(directory, "targets.json")
-            json_file.write_text(contents)
-            result = _read_json_file(json_file)
-
-            self.assertEqual(type(result), dict)
-
-    def test_invalid_path(self):
-        json_file = pathlib.Path("i_dont_exist")
-
-        with self.assertRaises(FileNotFoundError):
-            _read_json_file(json_file)
-
-    def test_malformed_json(self):
-        contents = """{
-            "Target_Name": {
-                []
-            }
-        }"""
-        with tempfile.TemporaryDirectory() as directory:
-            json_file = pathlib.Path(directory, "targets.json")
-            json_file.write_text(contents)
-
-            with self.assertRaises(ParsingTargetsJSONError):
-                _read_json_file(json_file)
-
-
 class TestGetTargetAttributes(TestCase):
-    @mock.patch("mbed_tools.targets._internal.target_attributes._read_json_file")
     @mock.patch("mbed_tools.targets._internal.target_attributes._extract_target_attributes")
     @mock.patch("mbed_tools.targets._internal.target_attributes.get_labels_for_target")
     @mock.patch("mbed_tools.targets._internal.target_attributes._extract_core_labels")
-    def test_gets_attributes_for_target(
-        self, extract_core_labels, get_labels_for_target, extract_target_attributes, read_json_file
-    ):
-        targets_json_path = pathlib.Path("mbed-os/targets/targets.json")
+    def test_gets_attributes_for_target(self, extract_core_labels, get_labels_for_target, extract_target_attributes):
+        targets_json_data = {"attrs": "vals"}
         target_name = "My_Target"
         build_attributes = {"attribute": "value"}
         extract_target_attributes.return_value = build_attributes
 
-        result = get_target_attributes(targets_json_path, target_name)
+        result = get_target_attributes(targets_json_data, target_name)
 
-        read_json_file.assert_called_once_with(targets_json_path)
-        extract_target_attributes.assert_called_once_with(read_json_file.return_value, target_name)
-        get_labels_for_target.assert_called_once_with(read_json_file.return_value, target_name)
+        extract_target_attributes.assert_called_once_with(targets_json_data, target_name)
+        get_labels_for_target.assert_called_once_with(targets_json_data, target_name)
         extract_core_labels.assert_called_once_with(build_attributes.get("core", None))
         self.assertEqual(result, extract_target_attributes.return_value)
 
 
 class TestExtractCoreLabels(TestCase):
-    @mock.patch("mbed_tools.targets._internal.target_attributes._read_json_file")
+    @mock.patch("mbed_tools.targets._internal.target_attributes.decode_json_file")
     def test_extract_core(self, read_json_file):
         core_labels = ["FOO", "BAR"]
         metadata = {"CORE_LABELS": {"core_name": core_labels}}
@@ -127,7 +84,7 @@ class TestExtractCoreLabels(TestCase):
         result = _extract_core_labels(None)
         self.assertEqual(result, set())
 
-    @mock.patch("mbed_tools.targets._internal.target_attributes._read_json_file")
+    @mock.patch("mbed_tools.targets._internal.target_attributes.decode_json_file")
     def test_no_labels(self, read_json_file):
         metadata = {"CORE_LABELS": {"not_the_same_core": []}}
         read_json_file.return_value = metadata
@@ -151,8 +108,11 @@ class TestApplyConfigOverrides(TestCase):
 
         self.assertEqual(config, _apply_config_overrides(config, overrides))
 
-    def test_overriding_non_existing_config(self):
+    def test_warns_when_attempting_to_override_undefined_config_parameter(self):
         config = {"foo": {"help": "Do a foo", "value": 0}}
         overrides = {"bar": 9}
-        with self.assertRaises(TargetsJsonConfigurationError):
+
+        with self.assertLogs(level="WARNING") as logger:
             _apply_config_overrides(config, overrides)
+
+        self.assertIn("bar=9", logger.output[0])
